Module array_tool::string
[−]
[src]
A string is a collection so we should have more methods for handling strings.
Structs
| GraphemeBytesIter |
A grapheme iterator that produces the bytes for each grapheme. |
Traits
| AfterWhitespace |
After whitespace |
| Justify |
Justify - expand line to given width. |
| Squeeze |
Squeeze - squeezes duplicate characters down to one each |
| SubstMarks |
Substitute string character for each index given. |
| ToGraphemeBytesIter |
ToGraphemeBytesIter - create an iterator to return bytes for each grapheme in a string. |
| WordWrap |
Word wrapping |